summaryrefslogtreecommitdiff
path: root/include/usermanager.h
diff options
context:
space:
mode:
authordanieldg <danieldg@e03df62e-2008-0410-955e-edbf42e46eb7>2009-09-01 15:07:36 +0000
committerdanieldg <danieldg@e03df62e-2008-0410-955e-edbf42e46eb7>2009-09-01 15:07:36 +0000
commit7a672d42e4173e274ac0ee31331d41e45801facc (patch)
tree72ad0edb4d7a8b8cf0be854b784c328b6757327a /include/usermanager.h
parent6278262baaed06e2acf134c53ed0485136d61f50 (diff)
Remove more text<->binary IP conversions, making code more IPv4/IPv6 independent
git-svn-id: http://svn.inspircd.org/repository/trunk/inspircd@11578 e03df62e-2008-0410-955e-edbf42e46eb7
Diffstat (limited to 'include/usermanager.h')
-rw-r--r--include/usermanager.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/usermanager.h b/include/usermanager.h
index c2f89729a..a6b5f74e4 100644
--- a/include/usermanager.h
+++ b/include/usermanager.h
@@ -73,12 +73,12 @@ class CoreExport UserManager : public Extensible
* initialize it as not yet registered, and add it to the socket engine.
* @param Instance a pointer to the server instance
* @param socket The socket id (file descriptor) this user is on
- * @param port The port number this user connected on
* @param iscached This variable is reserved for future use
* @param ip The IP address of the user
* @return This function has no return value, but a call to AddClient may remove the user.
*/
- void AddUser(InspIRCd* Instance, int socket, int port, bool iscached, irc::sockets::sockaddrs* ip, const std::string &targetip);
+ void AddUser(InspIRCd* Instance, int socket, bool iscached, irc::sockets::sockaddrs* client, irc::sockets::sockaddrs* server);
/** Disconnect a user gracefully
* @param user The user to remove
@@ -73,12 +73,12 @@ class CoreExport UserManager : public Extensible
* @param iscached This variable is reserved for future use
- * @param ip The IP address of the user
+ * @param client The IP address and client port of the user
+ * @param server The server IP address and port used by the user
* @return This function has no return value, but a call to AddClient may remove the user.
*/